@@ -276,7 +276,7 @@ public class AutoCryptServiceImpl implements AutoCryptService {
         if (startAttachment.contains("----BEGIN PGP MESSAGE----")) {
             String format = "";
             String begin = "";
-            String[] lines = startAttachment.split("\r");
+            String[] lines = normalize(startAttachment).split("\r");
             for (String line: lines) {
                 line = line.trim();
                 if (line.startsWith("Passphrase-Format")) {
@@ -291,9 +291,34 @@ public class AutoCryptServiceImpl implements AutoCryptService {
         return null;
     }
 
+    /**
+     * Normalize a pgp message to make sure each line ends with \r\n as needed by BC
+     * Returns message starting with the BEGIN PGP MESSAGE section
+     * normalize
+     *
+     * @param attachment
+     * @return message with each line ending in \r\n
+     */
+    private static String normalize(String attachment) {
+        int start = attachment.indexOf("----BEGIN PGP MESSAGE----");
+        if (start > -1) {
+            attachment = attachment.substring(start);
+            String[] lines = attachment.split("\n");
+            StringBuilder sb = new StringBuilder();
+            for (String line : lines) {
+                sb.append(line.trim());
+                sb.append("\r\n");
+            }
+            return sb.toString();
+
+        }
+        return attachment;
+    }
+
     @Override
     public PGPSecretKeyRing getKeyFromAttachment(String attachment, String key) throws OXException {
         try {
+            attachment = normalize(attachment);
             PGPSecretKeyRing secrKeyRing = AutoCryptCrypto.decryptSymmetricPGPObject(new ByteArrayInputStream(attachment.getBytes(StandardCharsets.UTF_8)), key.toCharArray());
             if (secrKeyRing == null) {
                 throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
@@ -301,7 +326,7 @@ public class AutoCryptServiceImpl implements AutoCryptService {
             return secrKeyRing;
         }
         catch(IOException e) {
-           throw GuardCoreExceptionCodes.IO_ERROR.create(e);
+            throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         } catch (PGPException e) {
             throw AutocryptExceptionCodes.UNABLE_DECRYPT.create(e);
         }
