@@ -58,6 +58,7 @@ import java.util.UUID;
 import org.apache.commons.codec.binary.Base64;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import com.openexchange.java.Strings;
 
 /**
  * {@link CipherUtil}
@@ -67,6 +68,12 @@ import org.slf4j.LoggerFactory;
 public final class CipherUtil {
 
     private static final Logger logger = LoggerFactory.getLogger(CipherUtil.class);
+
+    public static final String MD5 = "MD5";
+    public static final String SHA_1 = "SHA-1";
+    public static final String SHA_256 = "SHA-256";
+    public static final String SHA_512 = "SHA-512";
+
     protected static final char[] encoding = "ybndrfg8ejkmcpqxot1uwisza345h769".toCharArray();
 
     /**
@@ -78,8 +85,10 @@ public final class CipherUtil {
      */
     public static String getSHA(String password, String salt) {
         try {
-            if (password == null || salt == null) return null;
-            MessageDigest md = MessageDigest.getInstance("SHA-256");
+            if (password == null || salt == null) {
+                return null;
+            }
+            MessageDigest md = MessageDigest.getInstance(SHA_256);
             md.update(salt.getBytes("UTF-8"));
             byte[] hashbytes = md.digest(password.getBytes("UTF-8"));
 
@@ -91,6 +100,24 @@ public final class CipherUtil {
         }
     }
 
+    /**
+     * Performs a hash operation on a given set of bytes
+     *
+     * @param algorithm The algorithm to use for hashign
+     * @param bytes The bytes to has
+     * @return The hash in hex-string representation
+     * @throws NoSuchAlgorithmException
+     */
+    public static String getHash(String algorithm, byte[]...bytes) throws NoSuchAlgorithmException {
+        MessageDigest md = MessageDigest.getInstance(algorithm);
+        for (byte[] data : bytes) {
+            if (data != null) {
+                md.update(data);
+            }
+        }
+        return Strings.asHex(md.digest());
+    }
+
     /**
      * Get the MD5 hash from a string
      * @param data The string to get the has for
@@ -100,7 +127,7 @@ public final class CipherUtil {
      */
     public static String getMD5(String data) throws NoSuchAlgorithmException, UnsupportedEncodingException {
         StringBuffer ret = new StringBuffer();
-        MessageDigest md = MessageDigest.getInstance("MD5");
+        MessageDigest md = MessageDigest.getInstance(MD5);
         byte[] hashbytes = md.digest(data.getBytes("UTF-8"));
 
         for (int i = 0; i < hashbytes.length; i++) {
@@ -186,7 +213,7 @@ public final class CipherUtil {
     public static String getZbaseSHA (String data) {
         MessageDigest crypt;
         try {
-            crypt = MessageDigest.getInstance("SHA-1");
+            crypt = MessageDigest.getInstance(SHA_1);
             crypt.update(data.toLowerCase().getBytes("UTF-8"));
             return (encodeZBase32(crypt.digest()));
         } catch (NoSuchAlgorithmException | UnsupportedEncodingException e) {
