@@ -236,6 +236,10 @@ public enum GuardProperty {
      * Set to 0 if no expiration date
      */
     keyValidDays(3650),
+    /**
+     * Max key size allowed from remote servers. Default 150kb
+     */
+    maxRemoteKeySize(150000),
     /**
      * Outgoing e-mails all get assigned a mailID. This is usually in a format of
      * a random ID followed by a domain. By default, this domain will be
