@@ -75,7 +75,7 @@ public final class GuardCreateTableService extends AbstractCreateTableImpl {
         "  Salt varchar(40) COLLATE utf8_unicode_ci,\n" +
         "  cid int(11) NOT NULL DEFAULT '0',\n" +
         "  email varchar(250) COLLATE utf8_unicode_ci NOT NULL,\n" +
-        "  lastMod date DEFAULT NULL,\n" +
+        "  lastMod datetime DEFAULT NULL,\n" +
         "  question varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,\n" +
         "  answer varchar(1024) COLLATE utf8_unicode_ci DEFAULT NULL,\n" +
         "  misc varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,\n" +
