@@ -57,6 +57,7 @@ import com.openexchange.database.Assignment;
 import com.openexchange.database.AssignmentFactory;
 import com.openexchange.database.DBPoolingExceptionCodes;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.JdbcProperties;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
@@ -64,6 +65,7 @@ import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.database.exception.GuardDatabaseExceptionCodes;
 import com.openexchange.guard.database.utils.GuardConnectionWrapper;
+import com.openexchange.server.ServiceExceptionCode;
 
 /**
  * {@link GuardDatabaseServiceImpl}
@@ -292,9 +294,16 @@ public class GuardDatabaseServiceImpl implements GuardDatabaseService {
         return getWritableForInit(this.guardConfigurationService.getProperty(GuardProperty.oxGuardDatabaseHostname), properties);
     }
 
-    private Connection getWritableForInit(String host, Properties properties) throws OXException {
-        String connectionString = "jdbc:mysql://" + host;
+    private Connection getWritableForInit(String host, Properties propertyOptions) throws OXException {
+        JdbcProperties jdbcProperties = Services.getService(JdbcProperties.class);
+        if (jdbcProperties == null) {
+            throw ServiceExceptionCode.absentService(JdbcProperties.class);
+        }
 
+        String connectionString = "jdbc:mysql://" + host;
+        Properties properties = new Properties();
+        properties.putAll(jdbcProperties.getJdbcPropertiesRaw());  // Load defaults
+        properties.putAll(propertyOptions);
         properties.setProperty("user", this.guardConfigurationService.getProperty(GuardProperty.databaseUsername));
         properties.setProperty("password", this.guardConfigurationService.getProperty(GuardProperty.databasePassword));
         try {
@@ -350,7 +359,9 @@ public class GuardDatabaseServiceImpl implements GuardDatabaseService {
         databaseService.backWritable(connection);
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.guard.database.GuardDatabaseService#getDatabaseService()
      */
     @Override
