@@ -52,6 +52,7 @@ package com.openexchange.guard.database.osgi;
 import com.openexchange.database.AssignmentFactory;
 import com.openexchange.database.CreateTableService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.JdbcProperties;
 import com.openexchange.database.migration.DBMigrationExecutorService;
 import com.openexchange.groupware.update.DefaultUpdateTaskProviderService;
 import com.openexchange.groupware.update.UpdateTaskProviderService;
@@ -86,7 +87,7 @@ public class GuardDatabaseActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { DatabaseService.class, AssignmentFactory.class, GuardConfigurationService.class };
+        return new Class<?>[] { DatabaseService.class, JdbcProperties.class, AssignmentFactory.class, GuardConfigurationService.class };
     }
 
     /**
