@@ -50,7 +50,7 @@
 package com.openexchange.guard.dns.internal;
 
 import java.io.IOException;
-import java.util.Iterator;
+import java.util.List;
 import org.xbill.DNS.Flags;
 import org.xbill.DNS.Message;
 import org.xbill.DNS.RRset;
@@ -104,11 +104,10 @@ public class ValidatingResolverDecorator extends AbstractResolverDecorator {
      * @param m The message to remove the validation record from
      */
     private void clearValidationRecord(Message m) {
-        RRset[] answers = m.getSectionRRsets(Section.ANSWER);
+        List<RRset> answers = m.getSectionRRsets(Section.ANSWER);
         for (RRset rrset : answers) {
-            Iterator iterator = rrset.rrs();
-            while (iterator.hasNext()) {
-                Record record = (Record) iterator.next();
+            List<Record> records = rrset.rrs();
+            for (Record record : records) {
                 if (record.toString().contains(GUARD_DNS_VALIDATED_RECORD_VALUE)) {
                     m.removeRecord(record, Section.ANSWER);
                 }
@@ -125,7 +124,7 @@ public class ValidatingResolverDecorator extends AbstractResolverDecorator {
     private long getMaxTTL(Message message) {
         long maxTTL = 0;
         if (message != null) {
-            RRset[] rrsets = message.getSectionRRsets(Section.ANSWER);
+            List<RRset> rrsets = message.getSectionRRsets(Section.ANSWER);
             for (RRset rrset : rrsets) {
                 if (rrset.getTTL() > maxTTL) {
                     maxTTL = rrset.getTTL();
@@ -183,8 +182,7 @@ public class ValidatingResolverDecorator extends AbstractResolverDecorator {
         if (validationResult != null && !validationResult.isValidated()) {
             //Validation failed; Discarding the whole answer
             answer.getHeader().setRcode(Rcode.SERVFAIL);
-        }
-        else if(validationResult != null && validationResult.isValidated()) {
+        } else if (validationResult != null && validationResult.isValidated()) {
             //Adding a new Text record to indicate that validation has been done successfully by Guard.
             TXTRecord test = new TXTRecord(
                 query.getQuestion().getName(),
