@@ -62,13 +62,8 @@ import com.openexchange.exception.OXExceptionStrings;
  */
 public enum EncryptedItemsExceptionCodes implements DisplayableOXExceptionCode {
 
-    /**
-     * An SQL error occurred: %1$s
-     */
-    SQL_ERROR("An SQL error occurred: %1$s", CATEGORY_ERROR, 1),
-
     // Old proprietary Guard
-    NO_LONGER_SUPPORTED("Proprietary Guard format no longer supported", CATEGORY_ERROR, 2),
+    NO_LONGER_SUPPORTED("Proprietary Guard format no longer supported", EncryptedItemsExceptionMessages.NO_LONGER_SUPPORTED_MSG, CATEGORY_ERROR, 1),
 
     ;
 
