@@ -4,15 +4,14 @@ package com.openexchange.guard.encryption.internal;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
-
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.utils.DBUtils;
 import com.openexchange.guard.database.utils.GuardConnectionWrapper;
 import com.openexchange.guard.encryption.EncryptedItem;
 import com.openexchange.guard.encryption.EncryptedItemsStorage;
-import com.openexchange.guard.encryption.exceptions.EncryptedItemsExceptionCodes;
 import com.openexchange.guard.encryption.osgi.Services;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 
 /**
  * {@link EncryptedItemsStorageImpl} - Rest API implementation of {@link EncryptedItemsStorage}
@@ -38,7 +37,7 @@ public class EncryptedItemsStorageImpl implements EncryptedItemsStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw EncryptedItemsExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -77,7 +76,7 @@ public class EncryptedItemsStorageImpl implements EncryptedItemsStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw EncryptedItemsExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -111,7 +110,7 @@ public class EncryptedItemsStorageImpl implements EncryptedItemsStorage {
                 return resultSet.getString("XML");
             }
         } catch (SQLException e) {
-            throw EncryptedItemsExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
