@@ -58,8 +58,6 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.LongUtil;
-import com.openexchange.guard.configuration.GuardConfigurationService;
-import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.hkp.osgi.Services;
 import com.openexchange.guard.hkp.servlets.HkpServlet;
@@ -67,7 +65,6 @@ import com.openexchange.guard.hkp.utils.CheckWhitelist;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.AccountCreationService;
 import com.openexchange.guard.keymanagement.services.RecipKeyService;
-import com.openexchange.guard.keys.PGPKeyService;
 
 /**
  *
@@ -139,11 +136,11 @@ public class HKPIndex {
      */
     public String index(String requestIP, String search) throws OXException {
 
-        PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
+        HKPSearch hkpSearch = new HKPSearch();
         if (search.contains("@")) {
 
             //Searching for the given email
-            List<PGPPublicKeyRing> keyrings = pgpKeyService.getPublicKeyRing(assertUnwantedCharacters(search)); // zero cid for local search only
+            List<PGPPublicKeyRing> keyrings = hkpSearch.getPublicKeyRing(assertUnwantedCharacters(search)); // zero cid for local search only
 
             if (keyrings.size() > 0) {
                 logger.debug("Sending list of keys, length = " + keyrings.size());
@@ -165,7 +162,7 @@ public class HKPIndex {
                             Services.getService(AccountCreationService.class).createUserFor(key);
                         }
                         //Lookup the new created key
-                        keyrings = pgpKeyService.getPublicKeyRing(assertUnwantedCharacters(search));
+                        keyrings = hkpSearch.getPublicKeyRing(assertUnwantedCharacters(search));
                         logger.debug("Sending list of keys, length = " + keyrings.size());
                         return keyRingsToString(keyrings, false /* do not include subkeys */);
                     }
@@ -177,9 +174,9 @@ public class HKPIndex {
             PGPPublicKeyRing resultKeyRing = null;
             if (search.length() > 8) {
                 Long req_id = LongUtil.stringToLong(search);
-                resultKeyRing = pgpKeyService.getPublicKeyRingById(req_id, 0, 0);
+                resultKeyRing = hkpSearch.getPublicKeyRingById(req_id, 0, 0);
             } else {
-                resultKeyRing = pgpKeyService.getPublicKeyRingById(normalizeSearch(search), 0, 0);
+                resultKeyRing = hkpSearch.getPublicKeyRingById(normalizeSearch(search), 0, 0);
             }
             if (resultKeyRing != null) {
                 logger.debug("Sending list of keys, length = 1");
