@@ -99,9 +99,9 @@ public class HkpClientActivator extends HousekeepingActivator {
         //Setting up HKP client query logic in a decorator style
         GuardConfigurationService guardConfigService = getService(GuardConfigurationService.class);
         boolean forceTLSForHKPSRV = guardConfigService.getBooleanProperty(GuardProperty.forceTLSForHKPSRV);
-        RemoteHKPClientService remoteHKPClientService = new RemoteHKPClientService();
+        RemoteHKPClientService remoteHKPClientService = new RemoteHKPClientService(this);
         registerService(Reloadable.class, remoteHKPClientService);
-        registerService(HKPClientService.class, new CachingHKPClientService(new SRVHKPClientService(remoteHKPClientService, forceTLSForHKPSRV)));
+        registerService(HKPClientService.class, new CachingHKPClientService(new SRVHKPClientService(remoteHKPClientService, forceTLSForHKPSRV, this)));
     }
 
     /*
