@@ -17,10 +17,11 @@ public interface HKPClientService {
      *
      * @param clientToken an identification token put into the X-UI-INTERNAL-ACCOUNT-ID header, or null not not set the header
      * @param email The email to get the public keys for
+     * @param timeout Procedure should timeout after specified milliseconds
      * @return A list of public keys found for the given email
      * @throws OXException
      */
-    public Collection<RemoteKeyResult> find(String clientToken, String email) throws OXException;
+    public Collection<RemoteKeyResult> find(String clientToken, String email, int timeout) throws OXException;
 
     /**
      * Tries to find a specific key by email and ID
@@ -28,9 +29,10 @@ public interface HKPClientService {
      * @param clientToken an identification token put into the X-UI-INTERNAL-ACCOUNT-ID header, or null not not set the header
      * @param email The email to get the public keys for
      * @param id The ID of the key
+     * @param timeout Procedure should timeout after specified milliseconds
      * @return The public key for the given email and id
      * @throws OXException
      */
-    public RemoteKeyResult find(String clientToken, String email, Long id) throws OXException;
+    public RemoteKeyResult find(String clientToken, String email, Long id, int timeout) throws OXException;
 
 }
