@@ -416,9 +416,7 @@ public class GuardKeyServiceImpl implements GuardKeyService {
 
     @Override
     public boolean isRecoveryEnabled(int userId, int contextId) throws OXException {
-        KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
-        GuardKeys currentKey = ogKeyTableStorage.getCurrentKeyForUser(userId, contextId);
-
+        GuardKeys currentKey = getKeys(userId, contextId);
         if (currentKey != null && !Strings.isEmpty(currentKey.getRecovery())) {
             return true;
         }
@@ -426,9 +424,9 @@ public class GuardKeyServiceImpl implements GuardKeyService {
     }
 
     @Override
-    public String generatePassword() throws OXException {
+    public String generatePassword(int userId, int cid) throws OXException {
         GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
-        return cipherService.generateRandomPassword();
+        return cipherService.generateRandomPassword(userId, cid);
     }
 
     /*
