@@ -151,9 +151,11 @@ public class KeyImportServiceImpl implements KeyImportService {
                 publicKeyRing = PGPPublicKeyRing.insertPublicKey(publicKeyRing, key);
             }
         }
-        for (Iterator<PGPPublicKey> it2 = secretKeyRing.getExtraPublicKeys(); it2.hasNext();) {
-            PGPPublicKey key = it2.next();
-            PGPPublicKeyRing.insertPublicKey(publicKeyRing, key);
+        if (publicKeyRing != null) {
+            for (Iterator<PGPPublicKey> it2 = secretKeyRing.getExtraPublicKeys(); it2.hasNext();) {
+                PGPPublicKey key = it2.next();
+                PGPPublicKeyRing.insertPublicKey(publicKeyRing, key);
+            }
         }
         return publicKeyRing;
     }
@@ -277,6 +279,9 @@ public class KeyImportServiceImpl implements KeyImportService {
             newKeys.setKeyid(existingKeyMapping.getKeyId());
             //Getting the existing key
             GuardKeys existingKeys = guardKeyService.getKeys(existingKeyMapping.getKeyId());
+            if (existingKeys == null) {
+                throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create("Problem retrieving existing key");
+            }
 
             //Verify it has the same password
             if(existingKeys.hasPrivateKey() && !PGPUtil.verifyPassword(existingKeys.getPGPSecretKeyRing(), newPassword, existingKeys.getSalt())) {
@@ -345,6 +350,9 @@ public class KeyImportServiceImpl implements KeyImportService {
             newKeys.setKeyid(existingKeyMapping.getKeyId());
             //Getting the existing key
             GuardKeys existingKeys = guardKeyService.getKeys(existingKeyMapping.getKeyId());
+            if (existingKeys == null) {
+                throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create("Error while merging keys, problem retrieving existing key");
+            }
 
             //Merge the key rings
             PGPPublicKeyRing mergedKeyRings = PGPMergeUtil.mergeKeyRings(newKeys.getPGPPublicKeyRing(), existingKeys.getPGPPublicKeyRing());
