@@ -128,7 +128,7 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
             JsonObject json = new JsonObject();
             json.addProperty("user_id", keys.getUserid());
             json.addProperty("cid", keys.getContextid());
-            json.addProperty("email", userEmail);
+            json.addProperty("email", keys.getEmail());
             json.add("encr_password", new JsonPrimitive(newpass));
             GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
             returnJson.addProperty("auth", cipherService.encrypt(json.toString(), token));
