@@ -56,7 +56,7 @@ import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
-import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrategy;
+import com.openexchange.guard.keymanagement.services.lookup.AbstractRecipKeyLookupStrategy;
 
 /**
  * {@link GuardRecipKeyLookupStrategy} searches for a {@link RecipKey} through regular OX Guard users
@@ -64,7 +64,7 @@ import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrate
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v2.6.0
  */
-public class GuardRecipKeyLookupStrategy implements RecipKeyLookupStrategy{
+public class GuardRecipKeyLookupStrategy extends AbstractRecipKeyLookupStrategy{
 
     private static final Logger logger = LoggerFactory.getLogger(GuardRecipKeyLookupStrategy.class);
 
@@ -74,7 +74,7 @@ public class GuardRecipKeyLookupStrategy implements RecipKeyLookupStrategy{
     @Override
     public RecipKey lookup(String email, int timeout) throws OXException {
         GuardKeys key = Services.getService(GuardKeyService.class).getKeys(email);
-        return key != null ? new RecipKey(key) : null;
+        return (key != null) && hasValidEncryptionKey(key) ? new RecipKey(key) : null;
     }
 
 }
