@@ -62,9 +62,11 @@ import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPSecretKey;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
+import com.openexchange.guard.common.util.GuardMimeHeaders;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.commons.util.RecipKeyListUtils;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mime.encryptor.Encryptor;
 import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCodes;
@@ -85,7 +87,7 @@ import com.openexchange.pgp.mail.PGPMimeService;
  */
 public class GuardPGPMimeEncryptor extends Encryptor {
 
-    private HelpFileService helpFileService;
+    private final HelpFileService helpFileService;
 
     public GuardPGPMimeEncryptor (PGPCryptoService pgpCryptoService,
                                   HelpFileService helpFileService,
@@ -131,13 +133,15 @@ public class GuardPGPMimeEncryptor extends Encryptor {
             recips.add(senderKey);  // Add the sender here so it can be read in sent folder
 
             //Get additional help files to attach to the message
-            final List<BodyPart> helpFiles  = helpFileService.getHelpFiles(recips);
+            final List<BodyPart> helpFiles  = helpFileService.attachHelpFile(userid, cid) ?
+                helpFileService.getHelpFiles(userid, cid, RecipKeyListUtils.getLanguagesFor(recips)) :
+                null;
 
 
             PGPMimeService pgpMimeService = Services.getService(PGPMimeService.class);
             MimeMessage ret = null;
             if (msg.getPIN() != null) {  // If pin added, add header within encrypted email for sender to check
-                msg.getMessage().setHeader("X-OxGuard-PIN", msg.getPIN());
+                msg.getMessage().setHeader(GuardMimeHeaders.X_GUARD_PIN, msg.getPIN());
             }
             msg.getMessage().setRecipients(RecipientType.BCC, (String) null);  // remove BCC from Mime before encrypting
             if (msg.isSign() && !msg.isDraft()) {  // not signing Drafts
