@@ -88,6 +88,7 @@ import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.notification.exceptions.GuardNotificationExceptionCodes;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.translation.GuardTranslationService;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import net.htmlparser.jericho.Source;
 
 /**
@@ -112,7 +113,6 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         this.attachSenderIp = attachSenderIp;
     }
 
-
     private static Logger LOG = LoggerFactory.getLogger(GuardNotificationServiceImpl.class);
 
     @Override
@@ -122,15 +122,15 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
 
     @Override
     public void send(final JsonObject email, int senderUserId, int senderCid, String lang, final String senderIp) throws OXException {
-        send (email, null, "", senderUserId, senderCid, lang, getMessageID(senderUserId, senderCid), senderIp);
+        send(email, null, "", senderUserId, senderCid, lang, getMessageID(senderUserId, senderCid), senderIp);
     }
 
     @Override
     public void send(final JsonObject email, final List<BodyPart> attachments, int senderUserId, int senderCid, final String senderIp) throws OXException {
-        send(email, attachments, "", senderUserId, senderCid,  guardConfigService.getProperty(GuardProperty.defaultLanguage, senderUserId, senderCid), getMessageID(senderUserId, senderCid), senderIp);
+        send(email, attachments, "", senderUserId, senderCid, guardConfigService.getProperty(GuardProperty.defaultLanguage, senderUserId, senderCid), getMessageID(senderUserId, senderCid), senderIp);
     }
 
-    private boolean isLocal (int cid) {
+    private boolean isLocal(int cid) {
         return (cid > 0);
     }
 
@@ -214,7 +214,8 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
 
             if (!sender.equals("")) {
                 GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
-                fromaddr.setPersonal(translationService.getTranslation(GuardNotificationMessages.SENT_ON_BEHALF_OF, lang, ((fromaddr.getPersonal() == null) ? "" : (fromaddr.getPersonal().replace("\"", "") + " - ")) + fromaddr.getAddress().replace("<", "").replace(">", "")));
+                fromaddr.setPersonal(translationService.getTranslation(GuardNotificationMessages.SENT_ON_BEHALF_OF, lang,
+                    ((fromaddr.getPersonal() == null) ? "" : (fromaddr.getPersonal().replace("\"", "") + " - ")) + fromaddr.getAddress().replace("<", "").replace(">", "")));
                 fromaddr.setAddress(sender);
             }
             final String subject = email.get("subject").getAsString();
@@ -263,7 +264,7 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
             if (htmlcontent != null) {
                 try {
                     htmlcontent = checkInlineImages(htmlcontent, cids);
-                    htmlcontent = WrapUtils.wrapText(htmlcontent,MAX_MIME_LINE_LENGTH);
+                    htmlcontent = WrapUtils.wrapText(htmlcontent, MAX_MIME_LINE_LENGTH);
                 } catch (final Exception ex) {
                     LOG.error("Problem checking for inline mail images ", ex);
                 }
@@ -332,7 +333,8 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
                 msg.addHeader("Reply-To", msg.getFrom()[0].toString());
                 final InternetAddress fromaddr = (InternetAddress) msg.getFrom()[0];
                 GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
-                fromaddr.setPersonal(translationService.getTranslation(GuardNotificationMessages.SENT_ON_BEHALF_OF, lang, ((fromaddr.getPersonal() == null) ? "" : (fromaddr.getPersonal().replace("\"", "") + " - ")) + fromaddr.getAddress().replace("<", "").replace(">", "")));
+                fromaddr.setPersonal(translationService.getTranslation(GuardNotificationMessages.SENT_ON_BEHALF_OF, lang,
+                    ((fromaddr.getPersonal() == null) ? "" : (fromaddr.getPersonal().replace("\"", "") + " - ")) + fromaddr.getAddress().replace("<", "").replace(">", "")));
                 fromaddr.setAddress(sender);
                 msg.setFrom(fromaddr);
             }
@@ -349,11 +351,12 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
 
     /**
      * Add X-Originating-IP header if configured
+     *
      * @param msg
      * @param senderIp
      * @throws MessagingException
      */
-    private void addOrigIp (Message msg, String senderIp) throws MessagingException {
+    private void addOrigIp(Message msg, String senderIp) throws MessagingException {
         if (attachSenderIp) {  // If attach Originating IP header requested, add now
             senderIp = guardRatifierService.verifyIPAddress(senderIp);  // Verify
             if (senderIp != null) {
@@ -381,9 +384,14 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         } else {
             prop.put("mail.smtp.auth", "true");
         }
-        prop.put("mail.smtp.host", guardConfigService.getProperty(GuardProperty.guestSMTPServer, userId, cid));
-        prop.put("mail.smtp.port", guardConfigService.getIntProperty(GuardProperty.guestSMTPPort, userId, cid));
+        prop.put("mail.smtp.host", server);
+        prop.put("mail.smtp.port", port);
         if (guardConfigService.getBooleanProperty(GuardProperty.useStartTLS, userId, cid)) {
+            SSLSocketFactoryProvider factoryProvider = Services.getService(SSLSocketFactoryProvider.class);
+            if (factoryProvider != null) {
+                String socketFactoryClass = factoryProvider.getDefault().getClass().getName();
+                prop.put("mail.smtp.socketFactory.class", socketFactoryClass);
+            }
             prop.put("mail.smtp.starttls.enable", "true");
         }
         // Bug 55211, add guestSMTPMailFrom only for replies/system emails.
@@ -492,6 +500,4 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         return "<" + CipherUtil.getUUID() + "@" + mailIdDomain + ">";
     }
 
-
-
 }
