@@ -79,7 +79,7 @@ public class AbstractOXCalls {
     protected Header getBasicAuthenticationForCredentials(String userName, String password) throws OXException {
         try {
             String userPassword = userName + ":" + password;
-            return new BasicHeader("Authorization", "Basic " + new String(Base64.encodeBase64(userPassword.getBytes("UTF-8"))));
+            return new BasicHeader("Authorization", "Basic " + new String(Base64.encodeBase64(userPassword.getBytes("UTF-8")), "UTF-8"));
         } catch (UnsupportedEncodingException e) {
             throw OXApiExceptionCodes.BASIC_PWD_ENCODING_ERROR.create(e);
         }
