@@ -593,7 +593,9 @@ public class Api {
      * @return
      */
     private boolean checkError (JsonObject data, String objectName) {
-        if (data != null && data.has("data")) return false;
+        if (data != null && data.has("data")) {
+            return false;
+        }
         if (data != null && data.has("error")) {
             LOG.error("Problem getting " + objectName + " from middleware.  " + data.get("error").getAsString());
             return true;
@@ -961,7 +963,7 @@ public class Api {
     public String getPrimary() {
         try {
             String data = getConfig("mail");
-            JsonObject json = JsonUtil.parseAsJsonObject(data);
+            JsonObject json = data == null ? new JsonObject() : JsonUtil.parseAsJsonObject(data);
             if (json.has("data") && json.get("data").getAsJsonObject().has("defaultaddress")) {
                 return (json.get("data").getAsJsonObject().get("defaultaddress").getAsString());
             } else {
