@@ -102,6 +102,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
     private final AutoCryptStorageService autocryptService;
     private final GuardConfigurationService configurationService;
     private final HKPClientService hkpClient;
+    private static final String BEGIN_PGP_SIGNATURE_MARKER = "-----BEGIN PGP SIGNED MESSAGE-----";
 
     /**
      * Initializes a new {@link PGPMimeSigningServiceImpl}.
@@ -119,9 +120,9 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         super();
         this.guardKeyService = Objects.requireNonNull(guardKeyService, "guardKeyService must not be null");
         this.keyStorage = Objects.requireNonNull(keyStorage, "keyStorage must not be null");
-        this.autocryptService = Objects.requireNonNull(autocryptService,"autocryptService must not be null");
-        this.configurationService = Objects.requireNonNull(configurationService,"configurationService must not be null");
-        this.hkpClient = Objects.requireNonNull(hkpClient,"hkpClient must not be null");
+        this.autocryptService = Objects.requireNonNull(autocryptService, "autocryptService must not be null");
+        this.configurationService = Objects.requireNonNull(configurationService, "configurationService must not be null");
+        this.hkpClient = Objects.requireNonNull(hkpClient, "hkpClient must not be null");
     }
 
     private PGPKeyRetrievalStrategy getKeyRetrievalStrategyFor(UserIdentity user) {
@@ -143,14 +144,14 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
     }
 
     private <T> T requireSignedDataNotNull(T data) throws OXException {
-       if(data == null) {
-          throw PGPCoreServicesExceptionCodes.SIGNATURE_ERROR_NO_SIGNED_DATA_IN_EMAIL.create();
-       }
-       return data;
+        if (data == null) {
+            throw PGPCoreServicesExceptionCodes.SIGNATURE_ERROR_NO_SIGNED_DATA_IN_EMAIL.create();
+        }
+        return data;
     }
 
     private <T> T requireSignatureNotNull(T signature) throws OXException {
-        if(signature == null) {
+        if (signature == null) {
             throw PGPCoreServicesExceptionCodes.SIGNATURE_ERROR_NO_SIGNATURE_IN_EMAIL.create();
         }
         return signature;
@@ -196,10 +197,9 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
     }
 
     private InputStream asStream(String data) {
-       return new ByteArrayInputStream(data.getBytes(StandardCharsets.UTF_8));
+        return new ByteArrayInputStream(data.getBytes(StandardCharsets.UTF_8));
     }
 
-
     private String getContentInlineBody(String data, boolean convert) throws OXException {
         int i = data.indexOf("----BEGIN PGP SIGNATURE");
         if (i > -1) {
@@ -260,10 +260,10 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return null;
     }
 
-    private String cleanupSignature (String sig) {
+    private String cleanupSignature(String sig) {
         StringBuilder sb = new StringBuilder();
         String[] lines = sig.split("\r");
-        for (String line: lines) {
+        for (String line : lines) {
             sb.append(line.trim().replaceAll("<br>", "").replaceAll("[^\\x20-\\x7E]", ""));
             sb.append("\r");
         }
@@ -271,11 +271,11 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return (sb.toString());
     }
 
-    private String cleanupHTML (String data) {
+    private String cleanupHTML(String data) {
         StringBuilder sb = new StringBuilder();
         String[] lines = data.split("\r");
         int indentation = 0;  // HTML often indented
-        for (String line: lines) {
+        for (String line : lines) {
             if (line.contains("-----BEGIN")) {
                 indentation = line.indexOf("-----BEGIN");
             }
@@ -290,7 +290,6 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return (sb.toString());
     }
 
-
     private List<PGPSignatureVerificationResult> verifyMimeEmailSignature(MimeMessage message, UserIdentity userIdentity) throws OXException {
         InputStream signedData = null;
         InputStream signature = null;
@@ -300,13 +299,13 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         } catch (IOException | MessagingException e) {
             IOUtils.closeQuietly(signedData);  // If signature was null, close signedData
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
-        };
+        }
+        ;
 
         try {
             return new PGPSignatureVerifier(getKeyRetrievalStrategyFor(userIdentity))
                 .verifySignatures(signedData, signature);
-        }
-        catch(Exception e) {
+        } catch (Exception e) {
             return Arrays.asList(new PGPSignatureVerificationResult(e.getMessage()));
         } finally {
             IOUtils.closeQuietly(signature);
@@ -320,8 +319,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         try {
             return new PGPSignatureVerifier(getKeyRetrievalStrategyFor(userIdentity))
                 .verifySignatures(signedData, signature);
-        }
-        catch(Exception e) {
+        } catch (Exception e) {
             return Arrays.asList(new PGPSignatureVerificationResult(e.getMessage()));
         } finally {
             IOUtils.closeQuietly(signature);
@@ -330,19 +328,18 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
     }
 
     private boolean wasVerified(List<PGPSignatureVerificationResult> results) {
-       if(results != null && results.size() > 0) {
-           for(PGPSignatureVerificationResult result : results) {
-              if(!result.isVerified()) {
-                 return false;
-              }
-           }
-           return true;
-       }
-       return false;
+        if (results != null && results.size() > 0) {
+            for (PGPSignatureVerificationResult result : results) {
+                if (!result.isVerified()) {
+                    return false;
+                }
+            }
+            return true;
+        }
+        return false;
     }
 
-
-    private List<PGPSignatureVerificationResult> verifyInlineMessage (MimeMessage msg, UserIdentity userIdentity) throws OXException {
+    private List<PGPSignatureVerificationResult> verifyInlineMessage(MimeMessage msg, UserIdentity userIdentity) throws OXException {
         try {
             List<PGPSignatureVerificationResult> ret = new ArrayList<PGPSignatureVerificationResult>();
             Object content = msg.getContent();
@@ -376,7 +373,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
                                 } else {
                                     if (bp.getContentType() != null && bp.getContentType().toLowerCase().contains("text/plain")) {  // If the plaintext fails, we'll just fail the entire thing and return
                                         msg.saveChanges();
-                                        return Collections.emptyList();
+                                        return ret;
                                     }
                                 }
                             } catch (OXException ex) {
@@ -398,7 +395,6 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         }
     }
 
-
     private boolean isPGPMime(MimeMessage message) throws OXException {
         try {
             return message.getContentType().toLowerCase().contains("pgp-signature");
@@ -407,12 +403,51 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         }
     }
 
-    /* (non-Javadoc)
+    /**
+     * Peak through upper 2k only of an email to see if finds signed data
+     * isPGPSignedObject
+     *
+     * @param message
+     * @return
+     * @throws IOException
+     * @throws MessagingException
+     */
+    private static boolean isPGPSignedObject(MimeMessage message) throws IOException, MessagingException {
+        InputStream stream = message.getInputStream();
+        if (stream == null) {
+            return false;
+        }
+        byte[] peekedData = new byte[2048];
+        int read = stream.read(peekedData);
+        stream.close();
+        if (read > 0) {
+            String peekedContent = new String(peekedData, StandardCharsets.UTF_8);
+            return peekedContent.contains(BEGIN_PGP_SIGNATURE_MARKER);
+        }
+        return false;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
      * @see com.openexchange.guard.pgpcore.services.PGPMimeSigningService#verify(javax.mail.internet.MimeMessage, com.openexchange.guard.user.UserIdentity)
      */
     @Override
     public List<PGPSignatureVerificationResult> verify(MimeMessage mimeMessage, UserIdentity user) throws OXException {
-        List<PGPSignatureVerificationResult> verificationResults = isPGPMime(mimeMessage) ? verifyMimeEmailSignature(mimeMessage, user) : verifyInlineMessage(mimeMessage, user);
+        List<PGPSignatureVerificationResult> verificationResults;
+        if (isPGPMime(mimeMessage)) {
+            verificationResults = verifyMimeEmailSignature(mimeMessage, user);
+        } else {
+            try {
+                if (isPGPSignedObject(mimeMessage)) {  // Check if inline signed data found
+                    verificationResults = verifyInlineMessage(mimeMessage, user);
+                } else {
+                    verificationResults = Collections.emptyList();
+                }
+            } catch (IOException | MessagingException e) {
+                throw OXException.general("Error checking signature", e);
+            }
+        }
 
         //We need to compare the FROM header of the Message with the actual User ID of the signature's issuer in order ensure that the signature was really created by the sender of the email.
         FromHeaderVerifier.verify(mimeMessage, verificationResults);
