@@ -2,15 +2,19 @@
 package com.openexchange.guard.pgpcore.services.impl.osgi;
 
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.hkpclient.services.HKPClientService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
 import com.openexchange.guard.pgpcore.services.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPKeySigningService;
 import com.openexchange.guard.pgpcore.services.PGPMimeCryptoService;
+import com.openexchange.guard.pgpcore.services.PGPMimeSigningService;
 import com.openexchange.guard.pgpcore.services.PGPPacketService;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
@@ -20,6 +24,7 @@ import com.openexchange.guard.pgpcore.services.impl.EmailGuardKeyRingRetrievalSt
 import com.openexchange.guard.pgpcore.services.impl.PGPCryptoServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.PGPKeySigningServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.PGPMimeCryptoServiceImpl;
+import com.openexchange.guard.pgpcore.services.impl.PGPMimeSigningServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.PGPPacketServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.PGPSigningServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.TokenAuthenticationServiceImpl;
@@ -49,7 +54,9 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { GuardCipherFactoryService.class, GuardKeyService.class, GuardSessionService.class, OXUserService.class, OGPGPKeysStorage.class};
+        return new Class<?>[] { GuardCipherFactoryService.class, GuardKeyService.class,
+            GuardSessionService.class, OXUserService.class, OGPGPKeysStorage.class,
+            AutoCryptStorageService.class, GuardConfigurationService.class, HKPClientService.class };
     }
 
     /**
@@ -63,12 +70,11 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
         GuardKeyRingRetrievalStrategy guardKeyRingRetrievalStrategy = new CompositeGuardKeyRingRetrievalStrategy(new EmailGuardKeyRingRetrievalStrategy(getService(GuardKeyService.class)), new UserIDGuardKeyRingRetrievalStrategy(getService(GuardKeyService.class)));
         PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy = new DBKeyRetrievalStrategy(getService(GuardKeyService.class));
 
-        //create pgp crypto service
+        //Register the services
         PGPCryptoServiceImpl pgpCryptoService = new PGPCryptoServiceImpl(guardKeyRingRetrievalStrategy,
                                                                          getService(GuardKeyService.class),
-                                                                         getService(OGPGPKeysStorage.class));
-
-        //Register the services
+                                                                         getService(OGPGPKeysStorage.class),
+                                                                         getService(AutoCryptStorageService.class));
         registerService(TokenAuthenticationService.class,
             new TokenAuthenticationServiceImpl(guardKeyRingRetrievalStrategy,
                                                getService(GuardSessionService.class),
@@ -77,8 +83,17 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
         registerService(PGPCryptoService.class, pgpCryptoService);
         registerService(PGPMimeCryptoService.class, new PGPMimeCryptoServiceImpl(pgpCryptoService));
         registerService(PGPSigningService.class, new PGPSigningServiceImpl(guardKeyRingRetrievalStrategy, pgpKeyRetrievalStrategy));
+        registerService(PGPMimeSigningService.class, new PGPMimeSigningServiceImpl(
+            getService(GuardKeyService.class),
+            getService(OGPGPKeysStorage.class),
+            getService(AutoCryptStorageService.class),
+            getService(GuardConfigurationService.class),
+            getService(HKPClientService.class)));
         registerService(PGPPacketService.class, new PGPPacketServiceImpl());
-        registerService(PGPKeySigningService.class, new PGPKeySigningServiceImpl(pgpKeyRetrievalStrategy));
+        registerService(PGPKeySigningService.class, new PGPKeySigningServiceImpl(
+            getService(GuardKeyService.class),
+            getService(OGPGPKeysStorage.class),
+            getService(AutoCryptStorageService.class)));
     }
 
     /**
