@@ -93,7 +93,6 @@ public class AuthUtils {
         return GuardProperty.secureReply.getDefaultValue(Boolean.class);
     }
 
-
     /**
      * Gets a {@link UserIdentity} from the given {@link GuardUserSession}
      *
@@ -102,24 +101,34 @@ public class AuthUtils {
      * @throws OXException
      */
     public static UserIdentity getUserIdentityFrom(GuardUserSession guardUserSession) throws OXException {
+        return getUserIdentityFrom(guardUserSession.getGuardUserId(), guardUserSession.getGuardContextId());
+    }
+
+    /**
+     * Gets a {@link UserIdentity} from the given ids.
+     *
+     * @param guardUserId The ID of the guard user
+     * @param guardContextId The ID of guard user's context
+     * @return The {@link UserIdentity} from the given ids.
+     * @throws OXException
+     */
+    public static UserIdentity getUserIdentityFrom(int guardUserId, int guardContextId) throws OXException {
         //new user identity
         UserIdentity userIdentity = new UserIdentity(null);
 
         //add ox guard user information
-        OXGuardUser oxGuardUser = new OXGuardUser(
-            guardUserSession.getGuardUserId(),
-            guardUserSession.getGuardContextId());
+        OXGuardUser oxGuardUser = new OXGuardUser( guardUserId, guardContextId);
         userIdentity.setOXGuardUser(oxGuardUser);
 
         //get OX appsuite user information and add them
         OXUserService userService = Services.getService(OXUserService.class);
         //..get it by guard-id and guard-cid
-        OXUser oxUser = userService.getUser(guardUserSession.getGuardContextId(), guardUserSession.getGuardUserId());
+        OXUser oxUser = userService.getUser(guardContextId, guardUserId);
         //..we only use oxUser's email and name and have to adjust the userid and cid, because it can be possible that
         // multiple guests user exists with the same email address
         if (oxUser != null) {
-            oxUser.setContextId(guardUserSession.getContextId());
-            oxUser.setUserId(guardUserSession.getUserId());
+            oxUser.setContextId(guardContextId);
+            oxUser.setUserId(guardUserId);
             userIdentity.setOXUser(oxUser);
             userIdentity.setIdentity(oxUser.getEmail());
         }
@@ -179,7 +188,7 @@ public class AuthUtils {
             if (setting.isPrivatepass() == false) {// If config cascade value set as false, then use
                 json.add("ChangePrivate", new JsonPrimitive("false"));
             } else {
-                json.add("ChangePrivate", new JsonPrimitive(configService.getBooleanProperty(GuardProperty.okPrivate) ? "true" : "false"));
+                json.add("ChangePrivate", new JsonPrimitive(configService.getBooleanProperty(GuardProperty.okPrivate, id, cid) ? "true" : "false"));
             }
         }
 
@@ -193,13 +202,16 @@ public class AuthUtils {
 
         json.add("noRecovery", new JsonPrimitive(setting.isNorecovery()));
 
-        if (!configService.getBooleanProperty(GuardProperty.showStatus)) {
+        if (!configService.getBooleanProperty(GuardProperty.showStatus, id, cid)) {
             json.addProperty("status", false);
         }
-        json.addProperty("min_password_length", configService.getIntProperty(GuardProperty.minPasswordLength));
-        json.addProperty("password_length", configService.getIntProperty(GuardProperty.newPassLength));
+        json.addProperty("min_password_length", configService.getIntProperty(GuardProperty.minPasswordLength, id, cid));
+        json.addProperty("password_length", configService.getIntProperty(GuardProperty.newPassLength, id, cid));
 
         json.addProperty("secureReply", secureReply(id, cid));
+        if (cid > 0) {
+            json.addProperty("autoCryptEnabled", configService.getBooleanProperty(GuardProperty.autoCryptEnabled, id, cid));
+        }
 
         return (json);
     }
