@@ -172,12 +172,12 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
             throw GuardCoreExceptionCodes.DISABLED_ERROR.create("reset password");
         }
 
-        String newpass = keyService.generatePassword();
+        String newpass = keyService.generatePassword(keys.getUserid(), keys.getContextid());
         MailCreatorService mailCreatorService = Services.getService(MailCreatorService.class);
         JsonObject mail = mailCreatorService.getResetEmail(email, mailCreatorService.getFromAddress(email, email, keys.getUserid(), keys.getContextid()), newpass, defaultLanguage, templid, "", 0, 0);
 
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(mail, null);
+        guardNotificationService.send(mail, keys.getUserid(), keys.getContextid(), null);
 
         keyService.resetPassword(email, newpass);
     }
@@ -233,7 +233,7 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
     public void resetGuest(String email, boolean force) throws OXException {
         GuestResetService resetService = Services.getService(GuestResetService.class);
         GuardConfigurationService config = Services.getService(GuardConfigurationService.class);
-        resetService.reset(email, config.getIntProperty(GuardProperty.templateID), "", force, null);
+        resetService.reset(email, "", force, null);
     }
 
     @Override
