@@ -129,6 +129,7 @@ import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.update.GuardUpdateService;
 import com.openexchange.guard.update.internal.GuardKeysUpdater;
 import com.openexchange.guard.user.OXUserService;
+import com.openexchange.jslob.registry.JSlobServiceRegistry;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 import com.openexchange.startup.SignalHttpApiAvailabilityService;
@@ -167,12 +168,12 @@ public class GuardServiceActivator extends HousekeepingActivator {
             MimeEncryptionService.class, PGPKeyRingParser.class, ImportSystemPublicKey.class, PGPPacketService.class, GuardGuestService.class,
             PGPKeySigningService.class, ContactKeyService.class, SharingService.class, GuardGuestEMailMetadataService.class,
             GuestConverterService.class, GuestRedirectorService.class, GuestLookupService.class, SecondFactorService.class, GuardKeysUpdater.class,
-            AutoCryptService.class, AutoCryptStorageService.class};
+            AutoCryptService.class, AutoCryptStorageService.class };
     }
 
     @Override
     protected Class<?>[] getOptionalServices() {
-        return new Class[] { ActivityTrackingService.class };
+        return new Class[] { ActivityTrackingService.class, JSlobServiceRegistry.class };
     }
 
     /*
@@ -203,19 +204,18 @@ public class GuardServiceActivator extends HousekeepingActivator {
 
         GuardConfigurationService guardConfigurationService = getService(GuardConfigurationService.class);
 
-
         //Intialize key cache task
         if (guardConfigurationService.getBooleanProperty(GuardProperty.rsaCache)) {
             GuardCipherService AES_CBC = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
             PopulateKeyCacheTask populateKeyCacheTask = new PopulateKeyCacheTask(guardConfigurationService,
-                    getService(KeyCacheStorage.class),
-                    AES_CBC,
-                    getService(GuardMasterKeyService.class));
+                getService(KeyCacheStorage.class),
+                AES_CBC,
+                getService(GuardMasterKeyService.class));
             TimerService timerService = getService(TimerService.class);
             this.scheduledKeyCacheTask = timerService.scheduleAtFixedRate(populateKeyCacheTask,
-                    0,
-                    guardConfigurationService.getIntProperty(GuardProperty.keyCacheCheckInterval),
-                    TimeUnit.SECONDS);
+                0,
+                guardConfigurationService.getIntProperty(GuardProperty.keyCacheCheckInterval),
+                TimeUnit.SECONDS);
         }
         // Initializing daily cron jobs
         dailyJobScheduler = new DailyTaskScheduler(guardConfigurationService.getIntProperty(GuardProperty.cronHour));
@@ -233,7 +233,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
         }
 
         //Registering the OX Guard servlets
-        GuardServlets.registerServlets(getService(HttpService.class), getService(GuardConfigurationService.class));
+        GuardServlets.registerServlets(this);
     }
 
     /*
@@ -249,7 +249,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
         if (poolService != null) {
             poolService.closeAll();
         }
-        if(scheduledKeyCacheTask != null) {
+        if (scheduledKeyCacheTask != null) {
             scheduledKeyCacheTask.cancel();
         }
         if (dailyJobScheduler != null) {
