@@ -82,6 +82,8 @@ import com.openexchange.guard.servlets.authentication.GuestSessionValidator;
 import com.openexchange.guard.servlets.authentication.RestSessionValidator;
 import com.openexchange.guard.servlets.authentication.UserIdentityJsonParser;
 import com.openexchange.guard.servlets.authentication.UserIdentityParameterParser;
+import com.openexchange.guard.servlets.fileupload.AbstractTrackingFileItemFactory;
+import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.translation.GuardTranslator;
 import com.openexchange.guard.user.UserIdentity;
@@ -164,6 +166,7 @@ public abstract class GuardServletAction {
 
     /**
      * Gets the {@link GuardErrorResponseRenderer} which should be used to render exceptions for clients.
+     * 
      * @return The {@link GuardErrorResponseRenderer} which should be used for exception handling.
      */
     public GuardErrorResponseRenderer getErrorResponseRenderer() {
@@ -197,13 +200,28 @@ public abstract class GuardServletAction {
         if (guardUserSession == null) {
             guardUserSession = new RestSessionValidator().validateSession(request);
             logAction(request, guardUserSession);
-        }
-        else {
+        } else {
             logGuestAction(request, guardUserSession);
         }
         return guardUserSession;
     }
 
+    /**
+     * Cleanup any temporary files created handling the request
+     * cleanup
+     *
+     * @param request
+     */
+    private void cleanup(HttpServletRequest request) {
+        Object fileItemFactory = request.getServletContext().getAttribute(FileUploadHandler.REQUEST_TRACKER);
+        if (fileItemFactory == null) {
+            return;
+        }
+        if (fileItemFactory instanceof AbstractTrackingFileItemFactory) {
+            ((AbstractTrackingFileItemFactory) fileItemFactory).cleanup();
+        }
+    }
+
     /**
      * Performs the action after checking the authentication
      *
@@ -217,8 +235,7 @@ public abstract class GuardServletAction {
         //authenticate
         if (doAuthentication(request, guardUserSession, response)) {
             doActionInternal(request, response, guardUserSession);
-        }
-        else {
+        } else {
             if (guardUserSession == null) {  // If authentication failed, and no user session
                 GuardConfigurationService guardConfig = Services.getService(GuardConfigurationService.class);
                 Thread.sleep(guardConfig.getIntProperty(GuardProperty.sessionSyncDelay), 3000);
@@ -231,6 +248,7 @@ public abstract class GuardServletAction {
             }
             ServletUtils.sendResponse(response, HttpServletResponse.SC_UNAUTHORIZED, "Unauthorized");
         }
+        cleanup(request);
     }
 
     /**
@@ -292,7 +310,7 @@ public abstract class GuardServletAction {
      */
     protected String requirePassword(HttpServletRequest request, GuardUserSession userSession) throws OXException {
         String password = getPassword(request, userSession);
-        if(password == null) {
+        if (password == null) {
             throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("password or auth");
         }
         return password;
@@ -339,8 +357,8 @@ public abstract class GuardServletAction {
      */
     protected UserIdentity getUserIdentityFrom(HttpServletRequest request) throws OXException {
         return new UserIdentityParameterParser(Services.getService(GuardMasterKeyService.class),
-                                               Services.getService(GuardCipherFactoryService.class),
-                                               request).parse();
+            Services.getService(GuardCipherFactoryService.class),
+            request).parse();
     }
 
     /**
@@ -350,14 +368,12 @@ public abstract class GuardServletAction {
      * @return The parsed {@link UserIdentity}
      * @throws OXException
      */
-    protected UserIdentity requireUserIdentityFrom(HttpServletRequest request) throws OXException{
-        final UserIdentity userIdentity= getUserIdentityFrom(request);
+    protected UserIdentity requireUserIdentityFrom(HttpServletRequest request) throws OXException {
+        final UserIdentity userIdentity = getUserIdentityFrom(request);
         final boolean require = true;
         return requireOrReturn(userIdentity, require);
     }
 
-
-
     /**
      * Parses a {@link UserIdentity} from the given {@link JSONObject}
      *
@@ -428,7 +444,7 @@ public abstract class GuardServletAction {
      * @throws OXException
      */
     protected GuardTranslator getTranslatorFrom(GuardUserSession guardUserSession) throws OXException {
-       return new GuardTranslator(Services.getService(GuardTranslationService.class), guardUserSession.getLocale());
+        return new GuardTranslator(Services.getService(GuardTranslationService.class), guardUserSession.getLocale());
     }
 
     /**
