@@ -85,7 +85,7 @@ public class GuestFirstPasswordAction extends GuardServletAction {
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         GuardConfigurationService guardConfig = Services.getService(GuardConfigurationService.class);
-        if (guardConfig.getBooleanProperty(GuardProperty.newGuestsRequirePassword)) {  // If first password required, then we don't use this service
+        if (guardConfig.getBooleanProperty(GuardProperty.newGuestsRequirePassword, userSession.getUserId(), userSession.getContextId())) {  // If first password required, then we don't use this service
             throw GuestServletExceptionCodes.SERVICE_UNAVAILABLE.create();
         }
         GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
