@@ -21,7 +21,7 @@ public class ResetGuardAccountAction extends GuardServletAction {
             templid = 0;
         }
         String host = request.getServerName();
-        resetService.reset(email, templid, host, false, ServletUtils.getClientIP(request));
+        resetService.reset(email, host, false, ServletUtils.getClientIP(request));
         JsonObject json = new JsonObject();
         json.addProperty("data", "OK");;
         ServletUtils.sendJsonOK(response, json);
