@@ -96,4 +96,8 @@ public class ExternalPublicKeyInfoResponse {
     public PublicKeyRingInfoResponse getPublicRing() {
         return new PublicKeyRingInfoResponse(this.externalKeyRing.getKeyRing());
     }
+
+    public boolean isVerified() {
+        return this.externalKeyRing.isVerified();
+    }
 }
