@@ -49,6 +49,9 @@
 
 package com.openexchange.guard.servlets.keymanagement.responses;
 
+import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
 import java.util.Iterator;
 import org.bouncycastle.openpgp.PGPPublicKey;
@@ -56,6 +59,7 @@ import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.bouncycastle.openpgp.PGPSecretKey;
 import org.bouncycastle.openpgp.PGPSecretKeyRing;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
@@ -94,6 +98,10 @@ public class PublicKeyRingInfoResponse {
         return KeyExportUtil.export(this.keyRing);
     }
 
+    public String getHash() throws NoSuchAlgorithmException, IOException, OXException {
+        return CipherUtil.getHash(CipherUtil.SHA_512, getRing().getBytes(StandardCharsets.UTF_8));
+    }
+
     /**
      * Checks if the given public key has a corresponding, not empty, private key
      *
