@@ -51,8 +51,8 @@ package com.openexchange.guard.servlets.login;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import com.openexchange.guard.auth.LogoutHandler;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
-import com.openexchange.guard.internal.Auth;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
@@ -68,7 +68,7 @@ public class LogoutAction extends GuardServletAction {
 
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
-        new Auth().logout(new OxCookie(request.getCookies()));
+        new LogoutHandler().logout(userSession);
         ServletUtils.sendHtmlOK(response, "OK");
     }
 }
