@@ -107,16 +107,16 @@ public class EncryptAction extends GuardServletAction {
      */
     private List<String> getRecipientFromJson(JSONObject json) throws OXException, JSONException {
 
-        if(json.has(RECIPIENT_ARRAY_NAME)){
+        if (json.has(RECIPIENT_ARRAY_NAME)) {
             JSONArray recipients = json.getJSONArray(RECIPIENT_ARRAY_NAME);
             ArrayList<String> ret = new ArrayList<>();
-            for(int i = 0; i < recipients.length(); i++){
+            for (int i = 0; i < recipients.length(); i++) {
                 ret.add(recipients.getString(i));
             }
             if (json.has(SHARING_ARRAY_NAME)) {
                 JSONArray sharesArray = json.getJSONArray(SHARING_ARRAY_NAME);
                 ArrayList<String> shares = new ArrayList<>();
-                for(int i = 0; i < sharesArray.length(); i++){
+                for (int i = 0; i < sharesArray.length(); i++) {
                     if (!sharesArray.getJSONObject(i).has("email")) {
                         throw OXException.mandatoryField("email in sharing array");
                     }
@@ -126,8 +126,7 @@ public class EncryptAction extends GuardServletAction {
                 return sharingService.getAdditionalShareRecipients(ret, shares);
             }
             return ret;
-        }
-        else{
+        } else {
             throw GuardCoreExceptionCodes.JSON_PARAMETER_MISSING.create(RECIPIENT_ARRAY_NAME);
         }
     }
@@ -176,17 +175,19 @@ public class EncryptAction extends GuardServletAction {
 
                 //Encrypting the data to memory or disk.
                 DeferredFileOutputStream outputStream = fileUploadHandler.createOutputStream();
-                PGPCryptoService cryptoService = Services.getService(PGPCryptoService.class);
-                if (signingIdentity != null) {
-                    cryptoService.encryptSigned(dataStream, outputStream, armored, signingIdentity, recipients);
-                } else {
-                    cryptoService.encrypt(dataStream, outputStream, armored, recipients);
-                }
+                try {
+                    PGPCryptoService cryptoService = Services.getService(PGPCryptoService.class);
+                    if (signingIdentity != null) {
+                        cryptoService.encryptSigned(dataStream, outputStream, armored, signingIdentity, recipients);
+                    } else {
+                        cryptoService.encrypt(dataStream, outputStream, armored, recipients);
+                    }
 
-                //Send the data back to the client
-                try (InputStream responseStream = outputStream.isInMemory() ? new ByteArrayInputStream(outputStream.getData()) : new FileInputStream(outputStream.getFile());) {
-                    response.setContentType(CONTENT_TYPE_PGP_ENCRYPTED);
-                    IOUtils.copy(responseStream, response.getOutputStream());
+                    //Send the data back to the client
+                    try (InputStream responseStream = outputStream.isInMemory() ? new ByteArrayInputStream(outputStream.getData()) : new FileInputStream(outputStream.getFile());) {
+                        response.setContentType(CONTENT_TYPE_PGP_ENCRYPTED);
+                        IOUtils.copy(responseStream, response.getOutputStream());
+                    }
                 } finally {
                     //Cleanup if encrypted data has been buffered to disk.
                     if (!outputStream.isInMemory()) {
