@@ -54,6 +54,7 @@ import com.google.gson.JsonArray;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
 import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 
 /**
@@ -67,6 +68,11 @@ public class VerifyResultJsonFactory {
     private static final String RESULTS_PROPERTY = "results";
     private static final String VERIFIED_PROPERTY = "verified";
     private static final String DATE_PROPERTY = "signatureCreatedOn";
+    private static final String MISSING_PROPERTY = "missing";
+    private static final String ERROR_PROPERTY = "error";
+    private static final String ISSUER_USERIDS_PROPERTY = "issuerUserIds";
+    private static final String ISSUER_KEY_FINGERPRINT_PROPERTY = "issuerKeyFingerprint";
+    private static final String ISSUER_KEY_ID_PROPERTY = "issuerKeyId";
 
     public static JsonElement toJson(List<PGPSignatureVerificationResult> results) {
         JsonObject json = new JsonObject();
@@ -82,6 +88,18 @@ public class VerifyResultJsonFactory {
         JsonObject json = new JsonObject();
         json.addProperty(VERIFIED_PROPERTY, result.isVerified());
         json.addProperty(DATE_PROPERTY, result.getSignature().getCreationTime().getTime());
+        json.addProperty(MISSING_PROPERTY, result.isMissing());
+        if(result.getIssuerKey() != null) {
+            json.addProperty(ISSUER_KEY_ID_PROPERTY, result.getIssuerKey().getKeyID());
+            json.addProperty(ISSUER_KEY_FINGERPRINT_PROPERTY, PGPKeysUtil.getFingerPrint(result.getIssuerKey().getFingerprint()));
+        }
+        List<String> userIds = result.getIssuerUserIds();
+        JsonArray userIdsArray = new JsonArray(userIds.size());
+        for(String userId : userIds) {
+           userIdsArray.add(userId);
+        }
+        json.add(ISSUER_USERIDS_PROPERTY, userIdsArray);
+        json.addProperty(ERROR_PROPERTY, result.getError());
         return json;
     }
 }
