@@ -82,17 +82,19 @@ import com.openexchange.guard.user.UserIdentity;
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v7.8.4
  */
-public class DecryptMimeEmailAction extends GuardServletAction  {
+public class DecryptMimeEmailAction extends GuardServletAction {
+
     private static final String JSON_DATA_FIELD_NAME = "json";
     private static final String JSON_AUTH_FIELD_NAME = "guardAuth";
     private static final String MESSAGE_FIELD_NAME = "file";
 
-
     private GuardParsedMimeMessage parseMimeMessage(HttpServletRequest request, JSONObject json, InputStream messageStream, int userId, int contextId) throws MessagingException, JSONException, OXException, FileUploadException, IOException {
         return ParseIncoming.parse(request, json, messageStream, userId, contextId, null, null, false);
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     * 
      * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
      */
     @Override
@@ -106,11 +108,10 @@ public class DecryptMimeEmailAction extends GuardServletAction  {
         FileUploadHandler fileUploadHandler = new FileUploadHandler(Services.getService(GuardConfigurationService.class));
         JsonFileUploadHandler jsonFileUploadHandler = new JsonFileUploadHandler(fileUploadHandler);
         Collection<FileItem> items = fileUploadHandler.parseItems(request);
-        try(InputStream messageStream = fileUploadHandler.getFileItemStreamFrom(items, MESSAGE_FIELD_NAME, true);){
-
-            final JSONObject json = jsonFileUploadHandler.getJsonFrom(items,JSON_DATA_FIELD_NAME,true);
-            final JSONObject guardAuth = jsonFileUploadHandler.getJsonFrom(items,JSON_AUTH_FIELD_NAME, false);
+        try (InputStream messageStream = fileUploadHandler.getFileItemStreamFrom(items, MESSAGE_FIELD_NAME, true);) {
 
+            final JSONObject json = jsonFileUploadHandler.getJsonFrom(items, JSON_DATA_FIELD_NAME, false);
+            final JSONObject guardAuth = jsonFileUploadHandler.getJsonFrom(items, JSON_AUTH_FIELD_NAME, false);
 
             //Extracting user identity from the authenticationToken
             UserIdentity userIdentity = getUserIdentityFrom(guardAuth);
@@ -119,7 +120,7 @@ public class DecryptMimeEmailAction extends GuardServletAction  {
             }
 
             //This abuse wrapper does protect from wrong passwords inside of a valid auth-Token. Not from non-valid auth-tokens.
-            AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(AntiAbuseUtils.getAllowParameters(request, userId,  contextId, new String(userIdentity.getPassword())));
+            AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(AntiAbuseUtils.getAllowParameters(request, userId, contextId, new String(userIdentity.getPassword())));
             final UserIdentity closureUserIdentity = userIdentity;
             antiAbuseWrapper.doAction(new AntiAbuseAction<Void>() {
 
