@@ -85,13 +85,13 @@ public class PasswordReseter {
             throw GuardCoreExceptionCodes.DISABLED_ERROR.create("reset password");
         }
 
-        String newpass = keyService.generatePassword();
+        String newpass = keyService.generatePassword(userid, cid);
 
         MailCreatorService mailCreatorService = Services.getService(MailCreatorService.class);
         JsonObject mail = mailCreatorService.getResetEmail(secondaryEmail, mailCreatorService.getFromAddress(emailToRest, emailToRest, userid, cid), newpass, language, templid, "", userid, cid);
 
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(mail, null);
+        guardNotificationService.send(mail, userid, cid, null);
 
         keyService.resetPassword(emailToRest, newpass);
     }
