@@ -8,6 +8,7 @@ import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.activity.ActivityTrackingService;
 import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
+import com.openexchange.guard.common.session.FakeSession;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.guest.metadata.storage.GuardGuestEMailMetadataService;
 import com.openexchange.guard.guest.redirector.GuestRedirectorService;
@@ -20,6 +21,8 @@ import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.storage.Storage;
 import com.openexchange.guard.storage.cache.FileCacheItem;
 import com.openexchange.guard.storage.cache.FileCacheStorage;
+import com.openexchange.jslob.JSlobService;
+import com.openexchange.jslob.registry.JSlobServiceRegistry;
 
 /**
  * {@link UserDeleter} can be used for user or context based key deletion
@@ -97,6 +100,33 @@ public class UserDeleter {
         GuestRedirectorService redirector = Services.getService(GuestRedirectorService.class);
         redirector.deleteRedirect(userId, contextId);
     }
+    
+    /**
+     * If JSLob sevice available, try removing guard configurations assuming
+     * default "com.openexchange.jslob.config" serviceId
+     * tryDeleteConfig
+     *
+     * @param userId
+     * @param contextId
+     * @throws OXException
+     */
+    private static void tryDeleteConfig(int userId, int contextId) throws OXException {
+        final JSlobServiceRegistry jslobServiceReg = Services.getServiceLookup().getOptionalService(JSlobServiceRegistry.class);
+        if (jslobServiceReg == null)
+            return;
+        JSlobService service = jslobServiceReg.getJSlobService("com.openexchange.jslob.config");
+        if (service == null)
+            return;
+        try {
+            service.set("oxguard", null, new FakeSession(userId, contextId));
+        } catch (OXException ex) {
+            // If nothing found, no error
+            if (ex.getExceptionCode() != null && ex.getExceptionCode().getPrefix().equals("JSNCON") && ex.getExceptionCode().getNumber() == 4) {
+                return;
+            }
+            LOG.error("Cleanup of user configuration error during delete: ", ex);
+        }
+    }
 
 
     /**
@@ -177,6 +207,8 @@ public class UserDeleter {
         if (activityTracker != null) {
             activityTracker.removeActivityRecord(userId, contextId);
         }
+        // Cleanup UI configuration if able
+        tryDeleteConfig(userId, contextId);
 
     }
 }
